/**
 * 对口型服务器配置存储键名
 */
const LIP_SYNC_SERVER_KEY = 'lip_sync_server';

// 默认服务器配置
const DEFAULT_SERVER_URL = 'https://a9k866906pialdug-80.container.x-gpu.com';

/**
 * 获取对口型服务器配置
 * @returns {string} 服务器地址
 */
export const getLipSyncServer = () => {
  try {
    const serverUrl = localStorage.getItem(LIP_SYNC_SERVER_KEY);
    if (!serverUrl) {
      return DEFAULT_SERVER_URL;
    }
    return serverUrl;
  } catch (error) {
    console.error('获取对口型服务器配置失败:', error);
    return DEFAULT_SERVER_URL;
  }
};

/**
 * 保存对口型服务器配置
 * @param {string} serverUrl 服务器地址
 * @returns {boolean} 是否保存成功
 */
export const saveLipSyncServer = (serverUrl) => {
  try {
    localStorage.setItem(LIP_SYNC_SERVER_KEY, serverUrl);
    return true;
  } catch (error) {
    console.error('保存对口型服务器配置失败:', error);
    return false;
  }
};

/**
 * 重置对口型服务器配置为默认值
 */
export const resetLipSyncServer = () => {
  saveLipSyncServer(DEFAULT_SERVER_URL);
  return DEFAULT_SERVER_URL;
}; 